@@ -1,18 +1,18 @@
-from typing import Optional, Dict, List, AsyncIterator, Iterator, Literal
+from mikro.funcs import execute, subscribe, asubscribe, aexecute
+from typing import Optional, Literal, Iterator, Dict, AsyncIterator, List
+from mikro.traits import Vectorizable, Table, Representation, ROI
 from rath.scalars import ID
-from mikro.funcs import asubscribe, execute, aexecute, subscribe
 from mikro.scalars import (
     Parquet,
+    DataFrame,
     File,
     FeatureValue,
     ArrayInput,
     Store,
     MetricValue,
-    DataFrame,
 )
 from pydantic import Field, BaseModel
 from datetime import datetime
-from mikro.traits import Representation, Table, Vectorizable, ROI
 from enum import Enum
 from mikro.rath import MikroRath
 
@@ -111,6 +111,17 @@ class ROIType(str, Enum):
     "Unknown"
 
 
+class PandasDType(str, Enum):
+    OBJECT = "OBJECT"
+    INT64 = "INT64"
+    FLOAT64 = "FLOAT64"
+    BOOL = "BOOL"
+    CATEGORY = "CATEGORY"
+    DATETIME65 = "DATETIME65"
+    TIMEDELTA = "TIMEDELTA"
+    UNICODE = "UNICODE"
+
+
 class RoiTypeInput(str, Enum):
     """An enumeration."""
 
@@ -202,6 +213,51 @@ class InputVector(BaseModel, Vectorizable):
     "T-coordinate"
 
 
+class FeatureFragmentLabelRepresentation(Representation, BaseModel):
+    """A Representation is a multi-dimensional Array that can do what ever it wants
+
+
+    @elements/rep:latest"""
+
+    typename: Optional[Literal["Representation"]] = Field(alias="__typename")
+    id: ID
+
+
+class FeatureFragmentLabel(BaseModel):
+    typename: Optional[Literal["Label"]] = Field(alias="__typename")
+    instance: int
+    representation: Optional[FeatureFragmentLabelRepresentation]
+
+
+class FeatureFragment(BaseModel):
+    typename: Optional[Literal["Feature"]] = Field(alias="__typename")
+    label: Optional[FeatureFragmentLabel]
+    id: ID
+    key: str
+    "The sKesyss"
+    value: Optional[FeatureValue]
+    "Value"
+
+
+class LabelFragmentRepresentation(Representation, BaseModel):
+    """A Representation is a multi-dimensional Array that can do what ever it wants
+
+
+    @elements/rep:latest"""
+
+    typename: Optional[Literal["Representation"]] = Field(alias="__typename")
+    id: ID
+    name: Optional[str]
+    "Cleartext name"
+
+
+class LabelFragment(BaseModel):
+    typename: Optional[Literal["Label"]] = Field(alias="__typename")
+    instance: int
+    id: ID
+    representation: Optional[LabelFragmentRepresentation]
+
+
 class RepresentationFragmentSample(BaseModel):
     """Samples are storage containers for representations. A Sample is to be understood analogous to a Biological Sample. It existed in Time (the time of acquisiton and experimental procedure),
     was measured in space (x,y,z) and in different modalities (c). Sample therefore provide a datacontainer where each Representation of
@@ -436,21 +492,32 @@ class Expand_omerofileQuery(BaseModel):
         document = "fragment OmeroFile on OmeroFile {\n  id\n  name\n  file\n  type\n}\n\nquery expand_omerofile($id: ID!) {\n  omerofile(id: $id) {\n    ...OmeroFile\n  }\n}"
 
 
-class Search_omerofileQueryOmerofiles(BaseModel):
+class Search_omerofileQueryOptions(BaseModel):
     typename: Optional[Literal["OmeroFile"]] = Field(alias="__typename")
     value: ID
     label: str
 
 
 class Search_omerofileQuery(BaseModel):
-    omerofiles: Optional[List[Optional[Search_omerofileQueryOmerofiles]]]
+    options: Optional[List[Optional[Search_omerofileQueryOptions]]]
     "My samples return all of the users samples attached to the current user"
 
     class Arguments(BaseModel):
         search: str
 
     class Meta:
-        document = "query search_omerofile($search: String!) {\n  omerofiles(name: $search) {\n    value: id\n    label: name\n  }\n}"
+        document = "query search_omerofile($search: String!) {\n  options: omerofiles(name: $search) {\n    value: id\n    label: name\n  }\n}"
+
+
+class Expand_featureQuery(BaseModel):
+    feature: Optional[FeatureFragment]
+    "Get a single representation by ID"
+
+    class Arguments(BaseModel):
+        id: ID
+
+    class Meta:
+        document = "fragment Feature on Feature {\n  label {\n    instance\n    representation {\n      id\n    }\n  }\n  id\n  key\n  value\n}\n\nquery expand_feature($id: ID!) {\n  feature(id: $id) {\n    ...Feature\n  }\n}"
 
 
 class Get_labelQueryLabelforFeatures(BaseModel):
@@ -465,7 +532,8 @@ class Get_labelQueryLabelforFeatures(BaseModel):
 class Get_labelQueryLabelfor(BaseModel):
     typename: Optional[Literal["Label"]] = Field(alias="__typename")
     id: ID
-    features: List[Get_labelQueryLabelforFeatures]
+    features: Optional[List[Optional[Get_labelQueryLabelforFeatures]]]
+    "Features attached to this Label"
 
 
 class Get_labelQuery(BaseModel):
@@ -480,6 +548,17 @@ class Get_labelQuery(BaseModel):
         document = "query get_label($representation: ID!, $instance: Int!) {\n  labelFor(representation: $representation, instance: $instance) {\n    id\n    features {\n      id\n      key\n      value\n    }\n  }\n}"
 
 
+class Expand_labelQuery(BaseModel):
+    label: Optional[LabelFragment]
+    "Get a single representation by ID"
+
+    class Arguments(BaseModel):
+        id: ID
+
+    class Meta:
+        document = "fragment Label on Label {\n  instance\n  id\n  representation {\n    id\n    name\n  }\n}\n\nquery expand_label($id: ID!) {\n  label(id: $id) {\n    ...Label\n  }\n}"
+
+
 class Expand_representationQuery(BaseModel):
     """Creates a new representation"""
 
@@ -577,7 +656,7 @@ class Expand_thumbnailQuery(BaseModel):
 
 
 class Search_thumbnailsQueryThumbnails(BaseModel):
-    """Thumbnail(id, representation, image)"""
+    """Thumbnail(id, representation, image, major_color)"""
 
     typename: Optional[Literal["Thumbnail"]] = Field(alias="__typename")
     value: ID
@@ -596,7 +675,7 @@ class Search_thumbnailsQuery(BaseModel):
 
 
 class Image_for_thumbnailQueryImage(BaseModel):
-    """Thumbnail(id, representation, image)"""
+    """Thumbnail(id, representation, image, major_color)"""
 
     typename: Optional[Literal["Thumbnail"]] = Field(alias="__typename")
     path: Optional[str]
@@ -661,23 +740,21 @@ class Expand_tableQuery(BaseModel):
         document = "fragment Table on Table {\n  id\n  name\n  tags\n  store\n  creator {\n    email\n  }\n  sample {\n    id\n  }\n  representation {\n    id\n  }\n  experiment {\n    id\n  }\n}\n\nquery expand_table($id: ID!) {\n  table(id: $id) {\n    ...Table\n  }\n}"
 
 
-class Search_tablesQueryTables(Table, BaseModel):
+class Search_tablesQueryOptions(Table, BaseModel):
     typename: Optional[Literal["Table"]] = Field(alias="__typename")
-    id: ID
+    value: ID
     label: str
 
 
 class Search_tablesQuery(BaseModel):
-    tables: Optional[List[Optional[Search_tablesQueryTables]]]
+    options: Optional[List[Optional[Search_tablesQueryOptions]]]
     "My samples return all of the users samples attached to the current user"
 
     class Arguments(BaseModel):
         pass
 
     class Meta:
-        document = (
-            "query search_tables {\n  tables {\n    id: id\n    label: name\n  }\n}"
-        )
+        document = "query search_tables {\n  options: tables {\n    value: id\n    label: name\n  }\n}"
 
 
 class Get_sampleQuery(BaseModel):
@@ -691,7 +768,7 @@ class Get_sampleQuery(BaseModel):
         document = "fragment Sample on Sample {\n  name\n  id\n  representations {\n    id\n  }\n  meta\n  experiments {\n    id\n  }\n}\n\nquery get_sample($id: ID!) {\n  sample(id: $id) {\n    ...Sample\n  }\n}"
 
 
-class Search_sampleQuerySamples(BaseModel):
+class Search_sampleQueryOptions(BaseModel):
     """Samples are storage containers for representations. A Sample is to be understood analogous to a Biological Sample. It existed in Time (the time of acquisiton and experimental procedure),
     was measured in space (x,y,z) and in different modalities (c). Sample therefore provide a datacontainer where each Representation of
     the data shares the same dimensions. Every transaction to our image data is still part of the original acuqistion, so also filtered images are refering back to the sample
@@ -703,14 +780,14 @@ class Search_sampleQuerySamples(BaseModel):
 
 
 class Search_sampleQuery(BaseModel):
-    samples: Optional[List[Optional[Search_sampleQuerySamples]]]
+    options: Optional[List[Optional[Search_sampleQueryOptions]]]
     "All Samples"
 
     class Arguments(BaseModel):
         search: Optional[str] = None
 
     class Meta:
-        document = "query search_sample($search: String) {\n  samples(name: $search, limit: 20) {\n    value: id\n    label: name\n  }\n}"
+        document = "query search_sample($search: String) {\n  options: samples(name: $search, limit: 20) {\n    value: id\n    label: name\n  }\n}"
 
 
 class Expand_sampleQuery(BaseModel):
@@ -746,23 +823,23 @@ class Expand_experimentQuery(BaseModel):
         document = "fragment Experiment on Experiment {\n  id\n  name\n  creator {\n    email\n  }\n  meta\n}\n\nquery expand_experiment($id: ID!) {\n  experiment(id: $id) {\n    ...Experiment\n  }\n}"
 
 
-class Search_experimentQueryExperiments(BaseModel):
+class Search_experimentQueryOptions(BaseModel):
     """A Representation is a multi-dimensional Array that can do what ever it wants @elements/experiment"""
 
     typename: Optional[Literal["Experiment"]] = Field(alias="__typename")
-    id: ID
+    value: ID
     label: str
 
 
 class Search_experimentQuery(BaseModel):
-    experiments: Optional[List[Optional[Search_experimentQueryExperiments]]]
+    options: Optional[List[Optional[Search_experimentQueryOptions]]]
     "All Samples"
 
     class Arguments(BaseModel):
         search: Optional[str] = None
 
     class Meta:
-        document = "query search_experiment($search: String) {\n  experiments(name: $search, limit: 30) {\n    id: id\n    label: name\n  }\n}"
+        document = "query search_experiment($search: String) {\n  options: experiments(name: $search, limit: 30) {\n    value: id\n    label: name\n  }\n}"
 
 
 class Watch_roisSubscriptionRois(BaseModel):
@@ -918,11 +995,11 @@ class Create_labelMutation(BaseModel):
     class Arguments(BaseModel):
         instance: int
         representation: ID
-        creator: ID
+        creator: Optional[ID] = None
         name: Optional[str] = None
 
     class Meta:
-        document = "mutation create_label($instance: Int!, $representation: ID!, $creator: ID!, $name: String) {\n  createLabel(\n    instance: $instance\n    representation: $representation\n    creator: $creator\n    name: $name\n  ) {\n    id\n    instance\n  }\n}"
+        document = "mutation create_label($instance: Int!, $representation: ID!, $creator: ID, $name: String) {\n  createLabel(\n    instance: $instance\n    representation: $representation\n    creator: $creator\n    name: $name\n  ) {\n    id\n    instance\n  }\n}"
 
 
 class From_xarrayMutation(BaseModel):
@@ -1007,9 +1084,10 @@ class Create_thumbnailMutation(BaseModel):
     class Arguments(BaseModel):
         rep: ID
         file: File
+        major_color: Optional[str] = None
 
     class Meta:
-        document = "fragment Thumbnail on Thumbnail {\n  id\n  image\n}\n\nmutation create_thumbnail($rep: ID!, $file: ImageFile!) {\n  uploadThumbnail(rep: $rep, file: $file) {\n    ...Thumbnail\n  }\n}"
+        document = "fragment Thumbnail on Thumbnail {\n  id\n  image\n}\n\nmutation create_thumbnail($rep: ID!, $file: ImageFile!, $major_color: String) {\n  uploadThumbnail(rep: $rep, file: $file, majorColor: $major_color) {\n    ...Thumbnail\n  }\n}"
 
 
 class Create_metricMutation(BaseModel):
@@ -1109,9 +1187,10 @@ class Create_sampleMutation(BaseModel):
         creator: Optional[str] = None
         meta: Optional[Dict] = None
         experiments: Optional[List[Optional[ID]]] = None
+        tags: Optional[List[Optional[str]]] = None
 
     class Meta:
-        document = "mutation create_sample($name: String, $creator: String, $meta: GenericScalar, $experiments: [ID]) {\n  createSample(\n    name: $name\n    creator: $creator\n    meta: $meta\n    experiments: $experiments\n  ) {\n    id\n    name\n    creator {\n      email\n    }\n  }\n}"
+        document = "mutation create_sample($name: String, $creator: String, $meta: GenericScalar, $experiments: [ID], $tags: [String]) {\n  createSample(\n    name: $name\n    creator: $creator\n    meta: $meta\n    experiments: $experiments\n    tags: $tags\n  ) {\n    id\n    name\n    creator {\n      email\n    }\n  }\n}"
 
 
 class Create_experimentMutation(BaseModel):
@@ -1123,9 +1202,10 @@ class Create_experimentMutation(BaseModel):
         creator: Optional[str] = None
         meta: Optional[Dict] = None
         description: Optional[str] = None
+        tags: Optional[List[Optional[str]]] = None
 
     class Meta:
-        document = "fragment Experiment on Experiment {\n  id\n  name\n  creator {\n    email\n  }\n  meta\n}\n\nmutation create_experiment($name: String!, $creator: String, $meta: GenericScalar, $description: String) {\n  createExperiment(\n    name: $name\n    creator: $creator\n    description: $description\n    meta: $meta\n  ) {\n    ...Experiment\n  }\n}"
+        document = "fragment Experiment on Experiment {\n  id\n  name\n  creator {\n    email\n  }\n  meta\n}\n\nmutation create_experiment($name: String!, $creator: String, $meta: GenericScalar, $description: String, $tags: [String]) {\n  createExperiment(\n    name: $name\n    creator: $creator\n    description: $description\n    meta: $meta\n    tags: $tags\n  ) {\n    ...Experiment\n  }\n}"
 
 
 async def arequest(rath: MikroRath = None) -> Optional[RequestQueryRequest]:
@@ -1216,7 +1296,7 @@ def expand_omerofile(id: ID, rath: MikroRath = None) -> Optional[OmeroFileFragme
 
 async def asearch_omerofile(
     search: str, rath: MikroRath = None
-) -> Optional[List[Optional[Search_omerofileQueryOmerofiles]]]:
+) -> Optional[List[Optional[Search_omerofileQueryOptions]]]:
     """search_omerofile
 
 
@@ -1234,7 +1314,7 @@ async def asearch_omerofile(
 
 def search_omerofile(
     search: str, rath: MikroRath = None
-) -> Optional[List[Optional[Search_omerofileQueryOmerofiles]]]:
+) -> Optional[List[Optional[Search_omerofileQueryOptions]]]:
     """search_omerofile
 
 
@@ -1248,6 +1328,34 @@ def search_omerofile(
     return execute(Search_omerofileQuery, {"search": search}, rath=rath).omerofiles
 
 
+async def aexpand_feature(id: ID, rath: MikroRath = None) -> Optional[FeatureFragment]:
+    """expand_feature
+
+
+
+    Arguments:
+        id (ID): id
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[FeatureFragment]"""
+    return (await aexecute(Expand_featureQuery, {"id": id}, rath=rath)).feature
+
+
+def expand_feature(id: ID, rath: MikroRath = None) -> Optional[FeatureFragment]:
+    """expand_feature
+
+
+
+    Arguments:
+        id (ID): id
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[FeatureFragment]"""
+    return execute(Expand_featureQuery, {"id": id}, rath=rath).feature
+
+
 async def aget_label(
     representation: ID, instance: int, rath: MikroRath = None
 ) -> Optional[Get_labelQueryLabelfor]:
@@ -1292,6 +1400,34 @@ def get_label(
     ).label_for
 
 
+async def aexpand_label(id: ID, rath: MikroRath = None) -> Optional[LabelFragment]:
+    """expand_label
+
+
+
+    Arguments:
+        id (ID): id
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[LabelFragment]"""
+    return (await aexecute(Expand_labelQuery, {"id": id}, rath=rath)).label
+
+
+def expand_label(id: ID, rath: MikroRath = None) -> Optional[LabelFragment]:
+    """expand_label
+
+
+
+    Arguments:
+        id (ID): id
+        rath (mikro.rath.MikroRath, optional): The mikro rath client
+
+    Returns:
+        Optional[LabelFragment]"""
+    return execute(Expand_labelQuery, {"id": id}, rath=rath).label
+
+
 async def aexpand_representation(
     id: ID, rath: MikroRath = None
 ) -> Optional[RepresentationFragment]:
@@ -1492,7 +1628,7 @@ async def athumbnail(id: ID, rath: MikroRath = None) -> Optional[ThumbnailFragme
     """Thumbnail
 
 
-     thumbnail: Thumbnail(id, representation, image)
+     thumbnail: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
@@ -1508,7 +1644,7 @@ def thumbnail(id: ID, rath: MikroRath = None) -> Optional[ThumbnailFragment]:
     """Thumbnail
 
 
-     thumbnail: Thumbnail(id, representation, image)
+     thumbnail: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
@@ -1526,7 +1662,7 @@ async def aexpand_thumbnail(
     """expand_thumbnail
 
 
-     thumbnail: Thumbnail(id, representation, image)
+     thumbnail: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
@@ -1542,7 +1678,7 @@ def expand_thumbnail(id: ID, rath: MikroRath = None) -> Optional[ThumbnailFragme
     """expand_thumbnail
 
 
-     thumbnail: Thumbnail(id, representation, image)
+     thumbnail: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
@@ -1560,7 +1696,7 @@ async def asearch_thumbnails(
     """search_thumbnails
 
 
-     thumbnails: Thumbnail(id, representation, image)
+     thumbnails: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
@@ -1580,7 +1716,7 @@ def search_thumbnails(
     """search_thumbnails
 
 
-     thumbnails: Thumbnail(id, representation, image)
+     thumbnails: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
@@ -1598,7 +1734,7 @@ async def aimage_for_thumbnail(
     """image_for_thumbnail
 
 
-     image: Thumbnail(id, representation, image)
+     image: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
@@ -1616,7 +1752,7 @@ def image_for_thumbnail(
     """image_for_thumbnail
 
 
-     image: Thumbnail(id, representation, image)
+     image: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
@@ -1758,7 +1894,7 @@ def expand_table(id: ID, rath: MikroRath = None) -> Optional[TableFragment]:
 
 async def asearch_tables(
     rath: MikroRath = None,
-) -> Optional[List[Optional[Search_tablesQueryTables]]]:
+) -> Optional[List[Optional[Search_tablesQueryOptions]]]:
     """search_tables
 
 
@@ -1773,7 +1909,7 @@ async def asearch_tables(
 
 def search_tables(
     rath: MikroRath = None,
-) -> Optional[List[Optional[Search_tablesQueryTables]]]:
+) -> Optional[List[Optional[Search_tablesQueryOptions]]]:
     """search_tables
 
 
@@ -1826,11 +1962,11 @@ def get_sample(id: ID, rath: MikroRath = None) -> Optional[SampleFragment]:
 
 async def asearch_sample(
     search: Optional[str] = None, rath: MikroRath = None
-) -> Optional[List[Optional[Search_sampleQuerySamples]]]:
+) -> Optional[List[Optional[Search_sampleQueryOptions]]]:
     """search_sample
 
 
-     samples: Samples are storage containers for representations. A Sample is to be understood analogous to a Biological Sample. It existed in Time (the time of acquisiton and experimental procedure),
+     options: Samples are storage containers for representations. A Sample is to be understood analogous to a Biological Sample. It existed in Time (the time of acquisiton and experimental procedure),
         was measured in space (x,y,z) and in different modalities (c). Sample therefore provide a datacontainer where each Representation of
         the data shares the same dimensions. Every transaction to our image data is still part of the original acuqistion, so also filtered images are refering back to the sample
 
@@ -1847,11 +1983,11 @@ async def asearch_sample(
 
 def search_sample(
     search: Optional[str] = None, rath: MikroRath = None
-) -> Optional[List[Optional[Search_sampleQuerySamples]]]:
+) -> Optional[List[Optional[Search_sampleQueryOptions]]]:
     """search_sample
 
 
-     samples: Samples are storage containers for representations. A Sample is to be understood analogous to a Biological Sample. It existed in Time (the time of acquisiton and experimental procedure),
+     options: Samples are storage containers for representations. A Sample is to be understood analogous to a Biological Sample. It existed in Time (the time of acquisiton and experimental procedure),
         was measured in space (x,y,z) and in different modalities (c). Sample therefore provide a datacontainer where each Representation of
         the data shares the same dimensions. Every transaction to our image data is still part of the original acuqistion, so also filtered images are refering back to the sample
 
@@ -1974,11 +2110,11 @@ def expand_experiment(id: ID, rath: MikroRath = None) -> Optional[ExperimentFrag
 
 async def asearch_experiment(
     search: Optional[str] = None, rath: MikroRath = None
-) -> Optional[List[Optional[Search_experimentQueryExperiments]]]:
+) -> Optional[List[Optional[Search_experimentQueryOptions]]]:
     """search_experiment
 
 
-     experiments: A Representation is a multi-dimensional Array that can do what ever it wants @elements/experiment
+     options: A Representation is a multi-dimensional Array that can do what ever it wants @elements/experiment
 
 
     Arguments:
@@ -1994,11 +2130,11 @@ async def asearch_experiment(
 
 def search_experiment(
     search: Optional[str] = None, rath: MikroRath = None
-) -> Optional[List[Optional[Search_experimentQueryExperiments]]]:
+) -> Optional[List[Optional[Search_experimentQueryOptions]]]:
     """search_experiment
 
 
-     experiments: A Representation is a multi-dimensional Array that can do what ever it wants @elements/experiment
+     options: A Representation is a multi-dimensional Array that can do what ever it wants @elements/experiment
 
 
     Arguments:
@@ -2207,7 +2343,7 @@ def create_feature(
 async def acreate_label(
     instance: int,
     representation: ID,
-    creator: ID,
+    creator: Optional[ID] = None,
     name: Optional[str] = None,
     rath: MikroRath = None,
 ) -> Optional[Create_labelMutationCreatelabel]:
@@ -2218,7 +2354,7 @@ async def acreate_label(
     Arguments:
         instance (int): instance
         representation (ID): representation
-        creator (ID): creator
+        creator (Optional[ID], optional): creator.
         name (Optional[str], optional): name.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
@@ -2241,7 +2377,7 @@ async def acreate_label(
 def create_label(
     instance: int,
     representation: ID,
-    creator: ID,
+    creator: Optional[ID] = None,
     name: Optional[str] = None,
     rath: MikroRath = None,
 ) -> Optional[Create_labelMutationCreatelabel]:
@@ -2252,7 +2388,7 @@ def create_label(
     Arguments:
         instance (int): instance
         representation (ID): representation
-        creator (ID): creator
+        creator (Optional[ID], optional): creator.
         name (Optional[str], optional): name.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
@@ -2523,44 +2659,52 @@ def update_representation(
 
 
 async def acreate_thumbnail(
-    rep: ID, file: File, rath: MikroRath = None
+    rep: ID, file: File, major_color: Optional[str] = None, rath: MikroRath = None
 ) -> Optional[ThumbnailFragment]:
     """create_thumbnail
 
 
-     uploadThumbnail: Thumbnail(id, representation, image)
+     uploadThumbnail: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
         rep (ID): rep
         file (File): file
+        major_color (Optional[str], optional): major_color.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
         Optional[ThumbnailFragment]"""
     return (
-        await aexecute(Create_thumbnailMutation, {"rep": rep, "file": file}, rath=rath)
+        await aexecute(
+            Create_thumbnailMutation,
+            {"rep": rep, "file": file, "major_color": major_color},
+            rath=rath,
+        )
     ).upload_thumbnail
 
 
 def create_thumbnail(
-    rep: ID, file: File, rath: MikroRath = None
+    rep: ID, file: File, major_color: Optional[str] = None, rath: MikroRath = None
 ) -> Optional[ThumbnailFragment]:
     """create_thumbnail
 
 
-     uploadThumbnail: Thumbnail(id, representation, image)
+     uploadThumbnail: Thumbnail(id, representation, image, major_color)
 
 
     Arguments:
         rep (ID): rep
         file (File): file
+        major_color (Optional[str], optional): major_color.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
         Optional[ThumbnailFragment]"""
     return execute(
-        Create_thumbnailMutation, {"rep": rep, "file": file}, rath=rath
+        Create_thumbnailMutation,
+        {"rep": rep, "file": file, "major_color": major_color},
+        rath=rath,
     ).upload_thumbnail
 
 
@@ -2803,6 +2947,7 @@ async def acreate_sample(
     creator: Optional[str] = None,
     meta: Optional[Dict] = None,
     experiments: Optional[List[Optional[ID]]] = None,
+    tags: Optional[List[Optional[str]]] = None,
     rath: MikroRath = None,
 ) -> Optional[Create_sampleMutationCreatesample]:
     """create_sample
@@ -2819,6 +2964,7 @@ async def acreate_sample(
         creator (Optional[str], optional): creator.
         meta (Optional[Dict], optional): meta.
         experiments (Optional[List[Optional[ID]]], optional): experiments.
+        tags (Optional[List[Optional[str]]], optional): tags.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
@@ -2831,6 +2977,7 @@ async def acreate_sample(
                 "creator": creator,
                 "meta": meta,
                 "experiments": experiments,
+                "tags": tags,
             },
             rath=rath,
         )
@@ -2842,6 +2989,7 @@ def create_sample(
     creator: Optional[str] = None,
     meta: Optional[Dict] = None,
     experiments: Optional[List[Optional[ID]]] = None,
+    tags: Optional[List[Optional[str]]] = None,
     rath: MikroRath = None,
 ) -> Optional[Create_sampleMutationCreatesample]:
     """create_sample
@@ -2858,13 +3006,20 @@ def create_sample(
         creator (Optional[str], optional): creator.
         meta (Optional[Dict], optional): meta.
         experiments (Optional[List[Optional[ID]]], optional): experiments.
+        tags (Optional[List[Optional[str]]], optional): tags.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
         Optional[Create_sampleMutationCreatesample]"""
     return execute(
         Create_sampleMutation,
-        {"name": name, "creator": creator, "meta": meta, "experiments": experiments},
+        {
+            "name": name,
+            "creator": creator,
+            "meta": meta,
+            "experiments": experiments,
+            "tags": tags,
+        },
         rath=rath,
     ).create_sample
 
@@ -2874,6 +3029,7 @@ async def acreate_experiment(
     creator: Optional[str] = None,
     meta: Optional[Dict] = None,
     description: Optional[str] = None,
+    tags: Optional[List[Optional[str]]] = None,
     rath: MikroRath = None,
 ) -> Optional[ExperimentFragment]:
     """create_experiment
@@ -2887,6 +3043,7 @@ async def acreate_experiment(
         creator (Optional[str], optional): creator.
         meta (Optional[Dict], optional): meta.
         description (Optional[str], optional): description.
+        tags (Optional[List[Optional[str]]], optional): tags.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
@@ -2899,6 +3056,7 @@ async def acreate_experiment(
                 "creator": creator,
                 "meta": meta,
                 "description": description,
+                "tags": tags,
             },
             rath=rath,
         )
@@ -2910,6 +3068,7 @@ def create_experiment(
     creator: Optional[str] = None,
     meta: Optional[Dict] = None,
     description: Optional[str] = None,
+    tags: Optional[List[Optional[str]]] = None,
     rath: MikroRath = None,
 ) -> Optional[ExperimentFragment]:
     """create_experiment
@@ -2923,13 +3082,20 @@ def create_experiment(
         creator (Optional[str], optional): creator.
         meta (Optional[Dict], optional): meta.
         description (Optional[str], optional): description.
+        tags (Optional[List[Optional[str]]], optional): tags.
         rath (mikro.rath.MikroRath, optional): The mikro rath client
 
     Returns:
         Optional[ExperimentFragment]"""
     return execute(
         Create_experimentMutation,
-        {"name": name, "creator": creator, "meta": meta, "description": description},
+        {
+            "name": name,
+            "creator": creator,
+            "meta": meta,
+            "description": description,
+            "tags": tags,
+        },
         rath=rath,
     ).create_experiment
 
